/*******************************************************************************
* File Name: Comp_1.h  
* Version 1.50
*
*  Description:
*    This file contains the function prototypes and constants used in
*    the Analog Comparitor User Module.
*
*   Note:
*     
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_COMP_Comp_1_H) 
#define CY_COMP_Comp_1_H

#include "cytypes.h"
#include "cyfitter.h" 

#define Comp_1_RECALMODE 0u


/***************************************
   Conditional Compilation Parameters
****************************************/

/* PSoC3 ES2 or early */
#define Comp_1_PSOC3_ES2  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A)    && \
                                    (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_3A_ES2))                    
/* PSoC5 ES1 or early */
#define Comp_1_PSOC5_ES1  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_5A)    && \
                                    (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_5A_ES1))
/* PSoC3 ES3 or later */
#define Comp_1_PSOC3_ES3  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A)    && \
                                    (CYDEV_CHIP_REVISION_USED > CYDEV_CHIP_REVISION_3A_ES2))                    
/* PSoC5 ES2 or later */
#define Comp_1_PSOC5_ES2  ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_5A)    && \
                                    (CYDEV_CHIP_REVISION_USED > CYDEV_CHIP_REVISION_5A_ES1))
                                    

/***************************************
*       Type defines
***************************************/

/* Sleep Mode API Support */
typedef struct Comp_1_backupStruct
{
    uint8 enableState;         
}Comp_1_backupStruct;


/**************************************
*        Function Prototypes 
**************************************/

void    Comp_1_Start(void);
void    Comp_1_Stop(void)               ;
void    Comp_1_SetSpeed(uint8 speed)    ;
uint8   Comp_1_GetCompare(void)         ;
uint16  Comp_1_ZeroCal(void)            ;
void    Comp_1_LoadTrim(uint16 trimVal) ;
void Comp_1_Init(void)                  ; 
void Comp_1_Enable(void)                ;
void Comp_1_SaveConfig(void);
void Comp_1_RestoreConfig(void);
void Comp_1_Sleep(void);
void Comp_1_Wakeup(void)                ;
void Comp_1_PwrDwnOverrideEnable(void) ;
void Comp_1_PwrDwnOverrideDisable(void) ;


/**************************************
*           API Constants        
**************************************/

/* Power constants for SetSpeed() function */
#define Comp_1_SLOWSPEED   0x00u
#define Comp_1_HIGHSPEED   0x01u
#define Comp_1_LOWPOWER    0x02u


/***************************************
*         Trim Locations               
****************************************/

#define Comp_1_HS_TRIM_TR0    (CY_GET_XTND_REG8(Comp_1_ctComp__TRIM__TR0_HS))
#define Comp_1_HS_TRIM_TR1    (CY_GET_XTND_REG8(Comp_1_ctComp__TRIM__TR1_HS))


/**************************************
*           Parameter Defaults        
**************************************/

#define Comp_1_DEFAULT_SPEED       0u 
#define Comp_1_DEFAULT_HYSTERESIS  0u
#define Comp_1_DEFAULT_POLARITY    0u
#define Comp_1_DEFAULT_BYPASS_SYNC 0u
#define Comp_1_DEFAULT_PWRDWN_OVRD 0u

/**************************************
*             Registers        
**************************************/

#define Comp_1_CR      (* (reg8 *) Comp_1_ctComp__CR )   /* Config register   */
#define Comp_1_CR_PTR  (  (reg8 *) Comp_1_ctComp__CR )
#define Comp_1_CLK     (* (reg8 *) Comp_1_ctComp__CLK )  /* Comp clock comtrol register */
#define Comp_1_CLK_PTR (  (reg8 *) Comp_1_ctComp__CLK )
#define Comp_1_SW0     (* (reg8 *) Comp_1_ctComp__SW0 )  /* Routing registers */
#define Comp_1_SW0_PTR (  (reg8 *) Comp_1_ctComp__SW0 )
#define Comp_1_SW2     (* (reg8 *) Comp_1_ctComp__SW2 )
#define Comp_1_SW2_PTR (  (reg8 *) Comp_1_ctComp__SW2 )
#define Comp_1_SW3     (* (reg8 *) Comp_1_ctComp__SW3 )
#define Comp_1_SW3_PTR (  (reg8 *) Comp_1_ctComp__SW3 )
#define Comp_1_SW4     (* (reg8 *) Comp_1_ctComp__SW4 )
#define Comp_1_SW4_PTR (  (reg8 *) Comp_1_ctComp__SW4 )
#define Comp_1_SW6     (* (reg8 *) Comp_1_ctComp__SW6 )
#define Comp_1_SW6_PTR (  (reg8 *) Comp_1_ctComp__SW6 )

/* Trim registers */
/* PSoC3 ES2 or early, PSoC5 ES1 or early */
#if (Comp_1_PSOC3_ES2 || Comp_1_PSOC5_ES1)
    #define Comp_1_TR      (* (reg8 *) Comp_1_ctComp__TR )   /* Trim registers */
    #define Comp_1_TR_PTR  (  (reg8 *) Comp_1_ctComp__TR )
#endif

/* PSoC3 ES3 or later, PSoC5 ES2 or later */
#if (Comp_1_PSOC3_ES3 || Comp_1_PSOC5_ES2) 
    #define Comp_1_TR0         (* (reg8 *) Comp_1_ctComp__TR0 ) /* Trim register for P-type load */
    #define Comp_1_TR0_PTR     (  (reg8 *) Comp_1_ctComp__TR0 ) 
    #define Comp_1_TR1         (* (reg8 *) Comp_1_ctComp__TR1 ) /* Trim register for N-type load */
    #define Comp_1_TR1_PTR     (  (reg8 *) Comp_1_ctComp__TR1 ) 
#endif

#define Comp_1_WRK             (* (reg8 *) Comp_1_ctComp__WRK )  /* Working register - output */
#define Comp_1_WRK_PTR         (  (reg8 *) Comp_1_ctComp__WRK )
#define Comp_1_PWRMGR          (* (reg8 *) Comp_1_ctComp__PM_ACT_CFG )  /* Active Power manager */
#define Comp_1_PWRMGR_PTR      ( (reg8 *) Comp_1_ctComp__PM_ACT_CFG )
#define Comp_1_STBY_PWRMGR     (* (reg8 *) Comp_1_ctComp__PM_STBY_CFG )  /* Standby Power manager */
#define Comp_1_STBY_PWRMGR_PTR ( (reg8 *) Comp_1_ctComp__PM_STBY_CFG )


/**************************************
*       Register Constants        
**************************************/

/* CR (Comp Control Register)             */
#define Comp_1_CFG_MODE_MASK  0x78u
#define Comp_1_FILTER_ON      0x40u
#define Comp_1_HYST_OFF       0x20u
#define Comp_1_CAL_ON         0x10u
#define Comp_1_MX_AO          0x08u
#define Comp_1_PWRDWN_OVRD    0x04u

#define Comp_1_PWR_MODE_SHIFT 0x00u
#define Comp_1_PWR_MODE_MASK  (0x03u << Comp_1_PWR_MODE_SHIFT)
#define Comp_1_PWR_MODE_SLOW  (0x00u << Comp_1_PWR_MODE_SHIFT)
#define Comp_1_PWR_MODE_FAST  (0x01u << Comp_1_PWR_MODE_SHIFT)
#define Comp_1_PWR_MODE_ULOW  (0x02u << Comp_1_PWR_MODE_SHIFT)

/* CLK (Comp Clock Control Register)      */
#define Comp_1_BYPASS_SYNC    0x10u
#define Comp_1_SYNC_CLK_EN    0x08u
#define Comp_1_SYNCCLK_MASK   (Comp_1_BYPASS_SYNC | Comp_1_SYNC_CLK_EN)

/* SW3Routing Register definitions */
#define Comp_1_CMP_SW3_INPCTL_MASK    0x09u   /* SW3 bits for inP routing control */

/* TR (Comp Trim Register)     */
#define Comp_1_DEFAULT_CMP_TRIM  0x00u

/* PSoC3 ES2 or early, PSoC5 ES1 or early */
#if (Comp_1_PSOC3_ES2 || Comp_1_PSOC5_ES1)
    #define Comp_1_CMP_TRIM1_DIR  0x08u   /* Trim direction for N-type load for offset calibration */
    #define Comp_1_CMP_TRIM1_MASK 0x07u   /* Trim for N-type load for offset calibration */
    #define Comp_1_CMP_TRIM2_DIR  0x80u   /* Trim direction for P-type load for offset calibration */
    #define Comp_1_CMP_TRIM2_MASK 0x70u   /* Trim for P-type load for offset calibration */
#endif

/* PSoC3 ES3 or later, PSoC5 ES2 or later */
#if (Comp_1_PSOC3_ES3 || Comp_1_PSOC5_ES2)
    #define Comp_1_CMP_TR0_DIR 0x11u    /* Trim direction for N-type load for offset calibration */
    #define Comp_1_CMP_TR0_MASK 0x1Fu   /* Trim for N-type load for offset calibration */
    #define Comp_1_CMP_TR1_DIR 0x10u    /* Trim direction for P-type load for offset calibration */
    #define Comp_1_CMP_TR1_MASK 0x1Fu   /* Trim for P-type load for offset calibration */ 
#endif


/* WRK (Comp output working register)     */ 
#define Comp_1_CMP_OUT_MASK   Comp_1_ctComp__WRK_MASK /* Specific comparator out mask */

/* PM_ACT_CFG7 (Active Power Mode CFG Register)     */ 
#define Comp_1_ACT_PWR_EN     Comp_1_ctComp__PM_ACT_MSK /* Power enable mask */

/* PM_STBY_CFG7 (Standby Power Mode CFG Register)     */ 
#define Comp_1_STBY_PWR_EN     Comp_1_ctComp__PM_STBY_MSK /* Standby Power enable mask */

#endif /* CY_COMP_Comp_1_H */


/* [] END OF FILE  */
