/*******************************************************************************
* File Name: UARTTx_1.h  
* Version 1.0
*
* Description:
* This component implements a transmit only UART operating in 8-None-1 format.
*
********************************************************************************
* Copyright (2010), Cypress Semiconductor Corporation.
********************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress) and is 
* protected by and subject to worldwide patent protection (United States and 
* foreign), United States copyright laws and international treaty provisions. 
* Cypress hereby grants to licensee a personal, non-exclusive, non-transferable 
* license to copy, use, modify, create derivative works of, and compile the 
* Cypress Source Code and derivative works for the sole purpose of creating 
* custom software in support of licensee product to be used only in conjunction 
* with a Cypress integrated circuit as specified in the applicable agreement. 
* Any reproduction, modification, translation, compilation, or representation of 
* this software except as specified above is prohibited without the express 
* written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH 
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the 
* materials described herein. Cypress does not assume any liability arising out 
* of the application or use of any product or circuit described herein. Cypress 
* does not authorize its products for use as critical components in life-support 
* systems where a malfunction or failure may reasonably be expected to result in 
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of 
* such use and in doing so indemnifies Cypress against all charges. Use may be 
* limited by and subject to the applicable Cypress software license agreement. 
*******************************************************************************/

#if !defined(UARTTX_UARTTx_1_H)
#define UARTTX_UARTTx_1_H

#include "cytypes.h"
#include "cyfitter.h"
#include "CyLib.h"

/*************************************** 
*   Conditional Compilation Parameters
***************************************/

/* PSoC3 ES2 or early */
#define UARTTx_1_PSOC3_ES2   ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_3A) && \
                                      (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_3A_ES2))
                     
/* PSoC5 ES1 */
#define UARTTx_1_PSOC5_ES1   ((CYDEV_CHIP_MEMBER_USED == CYDEV_CHIP_MEMBER_5A) && \
                                      (CYDEV_CHIP_REVISION_USED <= CYDEV_CHIP_REVISION_5A_ES1)) 

/***************************************
*     Data Struct Definitions
***************************************/

/* Sleep Mode API Support */
typedef struct _UARTTx_1_backupStruct
{
    #if (UARTTx_1_PSOC3_ES2 || UARTTx_1_PSOC5_ES1)
        uint8 IntMask;
    #endif /* (UARTTx_1_PSOC3_ES2 || UARTTx_1_PSOC5_ES1) */    
} UARTTx_1_BACKUP_STRUCT;

/***************************************
*       Register Constants              
***************************************/
#define UARTTx_1_FIFO_CLR 	(1 << 0)
#define UARTTx_1_FIFO_LVL 	(1 << 2)

#define UARTTx_1_ST_MASK   (0x03u)

#define UARTTx_1_STATUS_INT_EN	(0x10u)

/***************************************
*             Registers                 
***************************************/
#define UARTTx_1_AUX_CONTROL_REG  (* (reg8 *) UARTTx_1_dpUART_u0__DP_AUX_CTL_REG)
#define UARTTx_1_STATUS_AUX_CONTROL_REG  (* (reg8 *) UARTTx_1_StsReg__STATUS_AUX_CTL_REG)
#define UARTTx_1_STATUS_REG       (* (reg8 *) UARTTx_1_StsReg__STATUS_REG)
#define UARTTx_1_STATUS_MASK_REG  (* (reg8 *) UARTTx_1_StsReg__MASK_REG)

#define UARTTx_1_FIFO_PTR	((reg8 *) UARTTx_1_dpUART_u0__F0_REG)
#define UARTTx_1_FIFO_REG  	(*(reg8 *) UARTTx_1_dpUART_u0__F0_REG)

/***************************************
*           API Constants               
***************************************/
#define UARTTx_1_NOT_FULL     (0x01u)
#define UARTTx_1_IDLE 	      (0x02u)

/***************************************
 *   Function Prototypes
 **************************************/
void UARTTx_1_Start(void)           ;
void UARTTx_1_Stop(void)            ;
void UARTTx_1_Init(void)            ;
void UARTTx_1_ClearFIFO(void)       ;
void UARTTx_1_WriteData(uint8 val) ;
void UARTTx_1_PutString(uint8 *string) ;
void UARTTx_1_PutArray(uint8 *string, uint16 byteCount) ;
uint8 UARTTx_1_ReadStatus(void) ;
void UARTTx_1_SetInterruptMode(uint8 interruptSource) ;
void UARTTx_1_SaveConfig(void) ;
void UARTTx_1_RestoreConfig(void) ;
void UARTTx_1_Sleep(void) ;
void UARTTx_1_Wakeup(void) ;

#endif  /* UARTTX_UARTTx_1_H */
