/*******************************************************************************
* File Name: UARTTx_1_PM.c  
* Version 1.0
*
* Description:
*  This file contains the setup, control and status commands to support 
*  component operations in low power mode.  
*
********************************************************************************
* Copyright (2010), Cypress Semiconductor Corporation.
********************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress) and is 
* protected by and subject to worldwide patent protection (United States and 
* foreign), United States copyright laws and international treaty provisions. 
* Cypress hereby grants to licensee a personal, non-exclusive, non-transferable 
* license to copy, use, modify, create derivative works of, and compile the 
* Cypress Source Code and derivative works for the sole purpose of creating 
* custom software in support of licensee product to be used only in conjunction 
* with a Cypress integrated circuit as specified in the applicable agreement. 
* Any reproduction, modification, translation, compilation, or representation of 
* this software except as specified above is prohibited without the express 
* written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH 
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED 
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the 
* materials described herein. Cypress does not assume any liability arising out 
* of the application or use of any product or circuit described herein. Cypress 
* does not authorize its products for use as critical components in life-support 
* systems where a malfunction or failure may reasonably be expected to result in 
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of 
* such use and in doing so indemnifies Cypress against all charges. Use may be 
* limited by and subject to the applicable Cypress software license agreement. 
*******************************************************************************/
#include "UARTTx_1.h"

static UARTTx_1_BACKUP_STRUCT  UARTTx_1_backup = 
{
    #if (UARTTx_1_PSOC3_ES2 || UARTTx_1_PSOC5_ES1)
        /* Interrupt Source (default no sources enabled) */
        0,
    #endif /* (UARTTx_1_PSOC3_ES2 || UARTTx_1_PSOC5_ES1) */ 
};

/*******************************************************************************
* Function Name: UARTTx_1_SaveConfig
********************************************************************************
*
* Summary:
*  Saves configuration.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  UARTTx_1_backup - modified when non-retention registers are saved.
*
*******************************************************************************/
void UARTTx_1_SaveConfig(void) 
{   
    /* Saves STATUSI MSK for PSoC3 ES2 and PSoC5 ES1 */
    #if (UARTTx_1_PSOC3_ES2 || UARTTx_1_PSOC5_ES1)                       
        UARTTx_1_backup.IntMask = UARTTx_1_STATUS_MASK_REG;
    #endif /* UARTTx_1_PSOC3_ES2 || UARTTx_1_PSOC5_ES1 */
}


/*******************************************************************************
* Function Name: UARTTx_1_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores configuration.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  UARTTx_1_backup - used when non-retention registers are restored.
*
*******************************************************************************/
void UARTTx_1_RestoreConfig(void) 
{    
    /* Restores STATUSI MSK registers for PSoC3 ES2 and PSoC5 ES1 */
    #if (UARTTx_1_PSOC3_ES2 || UARTTx_1_PSOC5_ES1)                         
        UARTTx_1_STATUS_MASK_REG = UARTTx_1_backup.IntMask;
		/* Reenable Interrupts */
		UARTTx_1_Init();
    #endif /* UARTTx_1_PSOC3_ES2 || UARTTx_1_PSOC5_ES1 */
}


/*******************************************************************************
* Function Name: UARTTx_1_Sleep
********************************************************************************
*
* Summary:
*  Prepares to go to sleep.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  UARTTx_1_backup - modified when non-retention registers are saved.
*
*******************************************************************************/
void UARTTx_1_Sleep(void) 
{
    /* Save registers configuration */
    UARTTx_1_SaveConfig();
    
    /* Stop component */
    UARTTx_1_Stop();
}


/*******************************************************************************
* Function Name: UARTTx_1_Wakeup
********************************************************************************
*
* Summary:
*  Prepares to wake up.
*
* Parameters:
*  None.
*
* Return:
*  None.
*
* Global Variables:
*  UARTTx_1_backup - used when non-retention registers are restored.
*
*******************************************************************************/
void UARTTx_1_Wakeup(void) 
{
    /* Restore registers values */
    UARTTx_1_RestoreConfig();
}


/* [] END OF FILE */

